@@ -1,4 +1,5 @@
 package Module::Starter::BuilderSet;
+# vi:et:sw=4 ts=4
 
 use strict;
 use warnings;
@@ -11,32 +12,27 @@ Module::Starter::BuilderSet - determine builder metadata
 
 =head1 VERSION
 
-Version 1.71_01
+Version 1.44
 
 =cut
 
-our $VERSION = '1.71_01';
-$VERSION = eval $VERSION;
+our $VERSION = '1.44';
 
 =head1 SYNOPSIS
 
-    use Module::Starter::BuilderSet;
+  use Module::Starter::BuilderSet;
 
-    my $builder_set = Module::Starter::BuilderSet->new;
-    my @supported_builders = $builder_set->supported_builders();
-    my $default_builder = $builder_set->default_builder();
-    my $output_file = $builder_set->file_for_builder($default_builder);
+ my $builder_set = Module::Starter::BuilderSet->new;
+ my @supported_builders = $builder_set->supported_builders();
+ my $default_builder = $builder_set->default_builder();
+ my $output_file = $builder_set->file_for_builder($default_builder);
 
-    my $create_method = $builder_set->method_for_builder($default_builder);
-    Module::Starter::Simple->$create_method($default_builder); # eeew.
+ my $create_method = $builder_set->method_for_builder($default_builder);
+ Module::Starter::Simple->$create_method($default_builder); # eeew.
 
-    my @build_commands = $builder_set->instructions_for_builder($default_builder);
-    my @builder_dependencies = $builder_set->deps_for_builder($default_builder);
-    my @compatible_builders = $builder_set->check_compatibility(@builder_list);
-
-    my $ms_simple    = Module::Starter::Simple->new();
-    my $build_method = $builder_set->manifest_method($builder);
-    $ms_simple->$build_method();
+ my @build_commands = $builder_set->instructions_for_builder($default_builder);
+ my @builder_dependencies = $builder_set->deps_for_builder($default_builder);
+ my @compatible_builders = $builder_set->check_compatibility(@builder_list);
 
 =head1 DESCRIPTION
 
@@ -59,45 +55,42 @@ sub new {
       {
        'Module::Build' =>
        {
-        file           => "Build.PL",
-        build_method   => "create_Build_PL",
-        build_deps     => [],
-        build_manifest => 'create_MB_MANIFEST',
-        instructions   => [ 'perl Build.PL',
-                            './Build',
-                            './Build test',
-                            './Build install',
-                          ],
+        file         => "Build.PL",
+        build_method => "create_Build_PL",
+        build_deps   => [],
+        instructions => [ 'perl Build.PL',
+                          './Build',
+                          './Build test',
+                          './Build install',
+                        ],
        },
        'Module::Install' =>
        {
-        file           => "Makefile.PL",
-        build_method   => "create_MI_Makefile_PL",
-        build_deps     => [],
-        build_manifest => 'create_MI_MANIFEST',
-        instructions   => [ 'perl Makefile.PL',
-                            'make',
-                            'make test',
-                            'make install',
-                          ],
+        file         => "Makefile.PL",
+        build_method => "create_MI_Makefile_PL",
+        build_deps   => [],
+        instructions => [ 'perl Makefile.PL',
+                          'make',
+                          'make test',
+                          'make install',
+                        ],
        },
        'ExtUtils::MakeMaker' =>
        {
-        file           => "Makefile.PL",
-        build_method   => "create_Makefile_PL",
-        build_manifest => 'create_EUMM_MANIFEST',
-        build_deps     => [ { command => 'make',
-                              aliases => [ 'make', 'gmake' ],
-                            },
-                            { command => 'chmod',
-                              aliases => [ 'chmod' ],
-                            },
-                          ],
-        instructions   => [ 'perl Makefile.PL',
-                            'make',
-                            'make test',
-                            'make install',
-                          ],
+        file         => "Makefile.PL",
+        build_method => "create_Makefile_PL",
+        build_deps   => [ { command => 'make',
+                            aliases => [ 'make', 'gmake' ],
+                          },
+                          { command => 'chmod',
+                            aliases => [ 'chmod' ],
+                          },
+                        ],
+        instructions => [ 'perl Makefile.PL',
+                          'make',
+                          'make test',
+                          'make install',
+                        ],
        }
       };
 
@@ -196,19 +189,6 @@ sub deps_for_builder {
     return @{ $self->_builder($builder)->{build_deps} };
 }
 
-=head2 C<< manifest_method($builder) >>
-
-This method returns the command to run to create the manifest according to the
-builder asked.
-
-=cut
-
-sub manifest_method {
-    my ( $self, $builder ) = @_;
-
-    return $self->_builder($builder)->{'build_manifest'};
-}
-
 =head2 C<< check_compatibility(@builders) >>
 
 This method accepts a list of builders and filters out the ones that
@@ -273,10 +253,10 @@ sub default_builder {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to the bugtracker for this project
-on GitHub at: L<https://github.com/xsawyerx/module-starter/issues>. I will be
-notified, and then you'll automatically be notified of progress on your bug
-as I make changes.
+Please report any bugs or feature requests to
+C<bug-module-starter at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
+be notified of progress on your bug as I make changes.
 
 =head1 AUTHOR
 
@@ -294,6 +274,5 @@ employers of the various contributors to the code.
 
 =cut
 
-1;
 
-# vi:et:sw=4 ts=4
+1;
